# Flask-hopak

Hopak based Flask admin interface lib. 

Uses:

- Twitter Bootstrap <http://twitter.github.com/bootstrap/>
- Chosen <http://harvesthq.github.com/chosen/>
- Backbone.js <http://backbonejs.org/>
- wysihtml5 <https://github.com/xing/wysihtml5/>
- bootstrap-wysihtml5 <https://github.com/jhollingworth/bootstrap-wysihtml5> v0.0.2
